fnss.topologies.topology.Topology.remove_node — FNSS 0.5.0 documentation

### Navigation

- index
- modules |
- modules |
- FNSS 0.5.0 documentation »

# fnss.topologies.topology.Topology.remove_node

`Topology.` `remove_node`(n)

  Remove node n.

  Removes the node n and all adjacent edges. Attempting to remove a non-existent node will raise an exception.

  Parameters : | n : node A node in the graph
  Raises : | NetworkXError : If n is not in the graph.

  See also

  `remove_nodes_from`

  Examples

      >>> G = nx.Graph()   # or DiGraph, MultiGraph, MultiDiGraph, etc
      >>> G.add_path([0,1,2])
      >>> G.edges()
      [(0, 1), (1, 2)]
      >>> G.remove_node(1)
      >>> G.edges()
      []

### Navigation

- index
- modules |
- modules |
- FNSS 0.5.0 documentation »